diff mbox series

[14/17] migration: Rename migration_channel_connect()

Message ID 20240125162528.7552-15-avihaih@nvidia.com (mailing list archive)
State New, archived
Headers show
Series migration: Add new migration channel connect and TLS upgrade APIs | expand

Commit Message

Avihai Horon Jan. 25, 2024, 4:25 p.m. UTC
The following patches will add a new API to create migration channels
with the same name, so rename migration_channel_connect() to
migration_channel_connect_main().
No functional changes intended.

Signed-off-by: Avihai Horon <avihaih@nvidia.com>
---
 migration/channel.h |  6 ++----
 migration/channel.c | 10 ++++------
 migration/exec.c    |  2 +-
 migration/fd.c      |  2 +-
 migration/file.c    |  2 +-
 migration/socket.c  |  2 +-
 6 files changed, 10 insertions(+), 14 deletions(-)
diff mbox series

Patch

diff --git a/migration/channel.h b/migration/channel.h
index 5bdb8208a7..1e36bdd866 100644
--- a/migration/channel.h
+++ b/migration/channel.h
@@ -20,10 +20,8 @@ 
 
 void migration_channel_process_incoming(QIOChannel *ioc);
 
-void migration_channel_connect(MigrationState *s,
-                               QIOChannel *ioc,
-                               const char *hostname,
-                               Error *error_in);
+void migration_channel_connect_main(MigrationState *s, QIOChannel *ioc,
+                                    const char *hostname, Error *error_in);
 
 int migration_channel_read_peek(QIOChannel *ioc,
                                 const char *buf,
diff --git a/migration/exec.c b/migration/exec.c
index 47d2f3b8fb..043fb3f14d 100644
--- a/migration/exec.c
+++ b/migration/exec.c
@@ -89,7 +89,7 @@  void exec_start_outgoing_migration(MigrationState *s, strList *command,
     }
 
     qio_channel_set_name(ioc, "migration-exec-outgoing");
-    migration_channel_connect(s, ioc, NULL, NULL);
+    migration_channel_connect_main(s, ioc, NULL, NULL);
     object_unref(OBJECT(ioc));
 }
 
diff --git a/migration/fd.c b/migration/fd.c
index 0eb677dcae..9d3ff249dc 100644
--- a/migration/fd.c
+++ b/migration/fd.c
@@ -39,7 +39,7 @@  void fd_start_outgoing_migration(MigrationState *s, const char *fdname, Error **
     }
 
     qio_channel_set_name(ioc, "migration-fd-outgoing");
-    migration_channel_connect(s, ioc, NULL, NULL);
+    migration_channel_connect_main(s, ioc, NULL, NULL);
     object_unref(OBJECT(ioc));
 }
 
diff --git a/migration/file.c b/migration/file.c
index 5d4975f43e..60cdaead1e 100644
--- a/migration/file.c
+++ b/migration/file.c
@@ -57,7 +57,7 @@  void file_start_outgoing_migration(MigrationState *s,
         return;
     }
     qio_channel_set_name(ioc, "migration-file-outgoing");
-    migration_channel_connect(s, ioc, NULL, NULL);
+    migration_channel_connect_main(s, ioc, NULL, NULL);
 }
 
 static gboolean file_accept_incoming_migration(QIOChannel *ioc,
diff --git a/migration/socket.c b/migration/socket.c
index 98e3ea1514..c55129dc9b 100644
--- a/migration/socket.c
+++ b/migration/socket.c
@@ -106,7 +106,7 @@  static void socket_outgoing_migration(QIOTask *task,
     }
 
 out:
-    migration_channel_connect(data->s, sioc, data->hostname, err);
+    migration_channel_connect_main(data->s, sioc, data->hostname, err);
     object_unref(OBJECT(sioc));
 }
diff --git a/migration/channel.c b/migration/channel.c
index 4022b2c9b8..c1f7c6d556 100644
--- a/migration/channel.c
+++ b/migration/channel.c
@@ -55,22 +55,20 @@  static void migration_channel_tls_handshake_main(QIOChannel *ioc, void *opaque,
 {
     MigrationState *s = opaque;
 
-    migration_channel_connect(s, ioc, NULL, err);
+    migration_channel_connect_main(s, ioc, NULL, err);
     object_unref(OBJECT(ioc));
 }
 
 /**
  * @migration_channel_connect - Create new outgoing migration channel
  *
  * @s: Current migration state
  * @ioc: Channel to which we are connecting
  * @hostname: Where we want to connect
  * @error: Error indicating failure to connect, free'd here
  */
-void migration_channel_connect(MigrationState *s,
-                               QIOChannel *ioc,
-                               const char *hostname,
-                               Error *error)
+void migration_channel_connect_main(MigrationState *s, QIOChannel *ioc,
+                                    const char *hostname, Error *error)
 {
     trace_migration_set_outgoing_channel(
         ioc, object_get_typename(OBJECT(ioc)), hostname, error);
@@ -55,22 +55,20 @@  static void migration_channel_tls_handshake_main(QIOChannel *ioc, void *opaque,
 
 /**
- * @migration_channel_connect - Create new outgoing migration channel
+ * @migration_channel_connect_main - Create new main outgoing migration channel
  *
  * @s: Current migration state